==> akismet-0.3.2.tar.gz: test/html_test.dart <==
/**
 * `dart:html` implementation of the unit tests.
 * @module tests.html
 */
library akismet.tests.html;

import 'core_test.dart' as core;
import 'dart:html';
import 'dart:js';
import 'package:akismet/html.dart';
import 'package:unittest/html_enhanced_config.dart';

/**
 * Runs the `dart:html` unit tests.
 * @class akismet.tests.html
 * @static
 */

/**
 * Application entry point.
 * @method main
 * @static
 */
void main() {
  useHtmlEnhancedConfiguration();

  // Enable tooltips.
  var $=context['jQuery'].apply;
  $([ '[data-toggle=tooltip]' ]).callMethod('tooltip');

  // Register button handlers.
  var button=(querySelector('#btn-submit') as ButtonElement);
  button.onClick.listen((event) {
    event.preventDefault();
    querySelectorAll('#form-unit-tests > .form-group').classes.remove('has-error');

    // Validate the user input.
    var blog=(querySelector('#blog-url') as InputElement);
    blog.value=blog.value.trim();
    if(blog.value.length==0) blog.value='http://dev.belin.io/akismet.dart';

    var serviceUrl=(querySelector('#service-url') as InputElement);
    serviceUrl.value=serviceUrl.value.trim();
    if(serviceUrl.value.length==0) serviceUrl.value='http://localhost:3000';

    var apiKey=(querySelector('#api-key') as InputElement);
    apiKey.value=apiKey.value.trim();
    if(apiKey.value.length==0) {
      apiKey.parent.parent.classes.add('has-error');
      apiKey.focus();
      $([ '#dialog-alert' ]).callMethod('modal', [ 'show' ]);
      return;
    }

    // Run the tests.
    core.main();
    var client=new Client(apiKey.value, Uri.parse(blog.value))..serviceUrl=Uri.parse(serviceUrl.value);
    new core.ClientTest(client).run();
  });
}

==> akismet-0.6.1.tar.gz: test/html_test.dart <==
/**
 * `dart:html` implementation of the unit tests.
 * @module test.html_test
 */
library akismet.tests.html;

// Module dependencies.
import 'core_test.dart' as core;
import 'dart:html';
import 'dart:js';
import 'package:akismet/html.dart';
import 'package:unittest/html_enhanced_config.dart';

/**
 * Runs the `dart:html` unit tests.
 * @class akismet.tests.html_test
 * @static
 */

/**
 * Application entry point.
 * @method main
 * @static
 */
void main() {
  useHtmlEnhancedConfiguration();
  var $=context['jQuery'].apply;

  // Enable tooltips.
  var isTouch=(TouchEvent.supported || window.navigator.maxTouchPoints>0);
  if(!isTouch) $([ '[data-toggle=tooltip]' ]).callMethod('tooltip', [ new JsObject.jsify({ 'placement': 'auto' }) ]);

  // Register button handlers.
  var button=(querySelector('#btn-submit') as ButtonElement);
  button.onClick.listen((event) {
    event.preventDefault();

    // Validate the user input.
    var blog=(querySelector('#blog-url') as InputElement);
    blog.value=blog.value.trim();
    if(blog.value.length==0) blog.value='https://bitbucket.org/cedx/akismet.dart';

    var serviceUrl=(querySelector('#service-url') as InputElement);
    serviceUrl.value=serviceUrl.value.trim();
    if(serviceUrl.value.length==0) serviceUrl.value='http://localhost:3000';

    var apiKey=(querySelector('#api-key') as InputElement);
    apiKey.value=apiKey.value.trim();
    if(apiKey.value.length>0) apiKey.parent.parent.classes.remove('has-error');
    else {
      apiKey.parent.parent.classes.add('has-error');
      apiKey.focus();
      $([ '#dialog-alert' ]).callMethod('modal', [ 'show' ]);
      return;
    }

    // Run the tests.
    core.main();
    var client=new Client(apiKey.value, Uri.parse(blog.value))
      ..isTest=true
      ..serviceUrl=Uri.parse(serviceUrl.value);

    new core.ClientTest(client).run();
  });
}
